/*
 * File:   nutsandvolts.c
 * Author: Fred
 *
 * Created on November 1, 2011, 3:09 PM
 */

#include <nutsandvolts.h>
#use fast_io(ALL)

#define led		PIN_E0
#define led_on		output_low(led)
#define led_off		output_high(led)
//******************************************************************
//*   SRAM ALLOCATIONS
//******************************************************************
int8 lastsec, time_temp, ascii_time;
//******************************************************************
//*   HARDWARE RTCC STRUCTURES
//******************************************************************
rtc_time_t nutsandvolts_time;
//******************************************************************
//*   LOW VOLTAGE DETECT INTERRUPT HANDLER
//******************************************************************
#INT_HLVD

void hlvdinterrupt_handler() {
    output_a(0xFF);
    output_b(0xFF);
    output_c(0xFF);
    output_d(0xFF);
    output_e(0xFF); //turn off all LEDs
    sleep();
}

void init(void) {
    setup_psp(PMP_DISABLED);
    setup_spi(SPI_MASTER | SPI_SCK_IDLE_LOW | SPI_CLK_DIV_64);
    setup_spi2(SPI_SS_DISABLED);
    setup_wdt(WDT_OFF);
    setup_timer_0(RTCC_OFF);
    setup_timer_1(T1_ENABLE_SOSC);
    setup_timer_2(T2_DISABLED, 0, 1);
    setup_timer_4(T4_DISABLED, 0, 1);
    setup_comparator(NC_NC_NC_NC);

    setup_rtc(RTC_ENABLE);

    setup_low_volt_detect(LVD_TRIGGER_BELOW | LVD_30); //30

    set_tris_a(0b11111111);

    set_tris_b(0b11101111);
    output_b(0b11011111);

    set_tris_c(0b10010011);
    output_c(0b11111111);

    set_tris_d(0b10011100);
    output_d(0b10011101);

    set_tris_e(0b00000000);
    output_e(0b00001111);

    nutsandvolts_time.tm_year = 11;
    nutsandvolts_time.tm_mon = 9;
    nutsandvolts_time.tm_mday = 29;
    nutsandvolts_time.tm_wday = 6;
    nutsandvolts_time.tm_hour = 14;
    nutsandvolts_time.tm_min = 34;
    nutsandvolts_time.tm_sec = 0;
    rtc_write(&nutsandvolts_time);
    lastsec = nutsandvolts_time.tm_sec;

    enable_interrupts(INT_HLVD); //LOW VOLTAGE INTERRUPT
    enable_interrupts(GLOBAL);

}

void main() {

    init();
    do {
        rtc_read(&nutsandvolts_time);
        if (nutsandvolts_time.tm_sec != lastsec) {
            time_temp = nutsandvolts_time.tm_hour;
            ascii_time = 0x00;
            if (time_temp > 0x09) {
                do {
                    ++ascii_time;
                    time_temp -= 0x0A;
                } while (time_temp > 0x09);
            }
            printf("%c%c:", ascii_time += 0x30, time_temp + 0x30);

            ascii_time = 0x00;
            time_temp = nutsandvolts_time.tm_min;
            if (time_temp > 0x09) {
                do {
                    ++ascii_time;
                    time_temp -= 0x0A;
                } while (time_temp > 0x09);
            }
            printf("%c%c:", ascii_time += 0x30, time_temp + 0x30);

            ascii_time = 0x00;
            time_temp = nutsandvolts_time.tm_sec;
            if (time_temp > 0x09) {
                do {
                    ++ascii_time;
                    time_temp -= 0x0A;
                } while (time_temp > 0x09);
            }
            printf("%c%c\r", ascii_time += 0x30, time_temp + 0x30);

            lastsec = nutsandvolts_time.tm_sec;
        }
    } while (1);

}
